@@ -1,6 +1,8 @@
 from .excel_module import get_df,create_dataframe,get_row,get_cell_value
 from .functions import haversine
-class LandManager:
+import os
+class landManager:
+    _instance = None
     def __init__(self,directory_js=None,default_polygon=None,column=None,value=None,default_index=1):
         directory_js = directory_js or {}
         if landManager._instance is not None:
